@@ -1,7 +1,9 @@
+# -*- coding: utf-8 -*-
+
 """This module provides the Expr class.  This attempts to create a
 consistent interface to SymPy's expressions.
 
-Copyright 2014--2019 Michael Hayes, UCECE
+Copyright 2014--2020 Michael Hayes, UCECE
 
 """
 
@@ -12,7 +14,7 @@ Copyright 2014--2019 Michael Hayes, UCECE
 
 from __future__ import division
 from .ratfun import Ratfun
-from .sym import sympify, symsimplify, j, omegasym, symdebug
+from .sym import sympify, symsimplify, j, omegasym, symdebug, AppliedUndef
 from .sym import capitalize_name, tsym, symsymbol, symbol_map
 from .state import state
 from .printing import pprint, pretty, print_str, latex
@@ -48,21 +50,21 @@ class ExprPrint(object):
 
     # Note, _repr_latex_ is handled at the end of this file.
         
-    def pretty(self):
+    def pretty(self, **kwargs):
         """Make pretty string."""
-        return pretty(self._pexpr)
+        return pretty(self._pexpr, **kwargs)
 
-    def prettyans(self, name):
+    def prettyans(self, name, **kwargs):
         """Make pretty string with LHS name."""
-        return pretty(sym.Eq(sympify(name), self._pexpr))
+        return pretty(sym.Eq(sympify(name), self._pexpr), **kwargs)
 
-    def pprint(self):
+    def pprint(self, **kwargs):
         """Pretty print"""
-        pprint(self._pexpr)
+        pprint(self._pexpr, **kwargs)
 
-    def pprintans(self, name):
+    def pprintans(self, name, **kwargs):
         """Pretty print string with LHS name."""
-        print(self.prettyans(name))
+        print(self.prettyans(name, **kwargs))
 
     def latex(self, **kwargs):
         """Make latex string."""
@@ -540,7 +542,11 @@ class Expr(ExprPrint, ExprMisc):
         xcls = x.__class__
 
         if isinstance(self, sExpr) and isinstance(x, sExpr):
-            if self.assumptions == x.assumptions:
+            if self.is_causal and x.is_causal:
+                assumptions = {'causal' : True}
+            elif self.is_dc and x.is_dc:
+                assumptions = self.assumptions
+            elif self.is_ac and x.is_ac:
                 assumptions = self.assumptions
         
         if cls == xcls:
@@ -781,8 +787,12 @@ class Expr(ExprPrint, ExprMisc):
         """Return imaginary part."""
 
         assumptions = self.assumptions.copy()
-        assumptions['real'] = True
+        if self.is_real:
+            dst = self.__class__(0, **assumptions)
+            dst.part = 'imaginary'
+            return dst
         
+        assumptions['real'] = True
         dst = self.__class__(symsimplify(sym.im(self.expr)), **assumptions)
         dst.part = 'imaginary'
         return dst
@@ -817,33 +827,33 @@ class Expr(ExprPrint, ExprMisc):
     
     @property
     def N(self):
-        """Return numerator of rational function."""
+        """Return numerator of rational function.
+        The denominator is chosen so that it is a polynomial."""
 
         return self.numerator
 
     @property
     def D(self):
-        """Return denominator of rational function."""
+        """Return denominator of rational function.
+        The denominator is chosen so that it is a polynomial."""
 
         return self.denominator
 
     @property
     def numerator(self):
-        """Return numerator of rational function."""
+        """Return numerator of rational function.
+        The denominator is chosen so that it is a polynomial."""
 
-        if self._ratfun is None:
-            return self.copy()
-
-        return self.__class__(self._ratfun.numerator)
+        N, D = self.as_N_D()
+        return N
 
     @property
     def denominator(self):
-        """Return denominator of rational function."""
+        """Return denominator of rational function.
+        The denominator is chosen so that it is a polynomial."""
 
-        if self._ratfun is None:
-            return self.__class__(1)
-        
-        return self.__class__(self._ratfun.denominator)
+        N, D = self.as_N_D()
+        return D
 
     def rationalize_denominator(self):
         """Rationalize denominator by multiplying numerator and denominator by
@@ -888,9 +898,12 @@ class Expr(ExprPrint, ExprMisc):
         N = self.N.expr
         D = self.D.expr
 
-        return self.__class__(sym.Mul(sym.Mul(N, factor, evaluate=False),
-                                      1 / sym.Mul(D, factor, evaluate=False),
-                                      evaluate=False))
+        N = sym.Mul(N, factor, evaluate=False)
+        D = sym.Mul(D, factor, evaluate=False)
+        ID = sym.Pow(D, -1, evaluate=False)
+        expr = sym.Mul(N, ID, evaluate=False)
+        
+        return self.__class__(expr)
     
     def merge_assumptions(self, **assumptions):
         
@@ -903,13 +916,15 @@ class Expr(ExprPrint, ExprMisc):
         """Return magnitude"""
 
         if self.is_real:
-            dst = self
-        else:
-            R = self.rationalize_denominator()
-            N = R.N
-            Dnew = R.D
-            Nnew = sqrt((N.real**2 + N.imag**2).simplify())
-            dst = Nnew / Dnew
+            dst = self.copy()
+            dst.part = 'real'            
+            return dst
+
+        R = self.rationalize_denominator()
+        N = R.N
+        Dnew = R.D
+        Nnew = sqrt((N.real**2 + N.imag**2).simplify())
+        dst = Nnew / Dnew
 
         dst.part = 'magnitude'
         return dst
@@ -924,7 +939,7 @@ class Expr(ExprPrint, ExprMisc):
     def sign(self):
         """Return sign"""
 
-        return self.__class__(sym.sign(self.expr))
+        return self.__class__(sym.sign(self.expr), **self.assumptions)
 
     @property
     def dB(self):
@@ -1188,35 +1203,38 @@ class Expr(ExprPrint, ExprMisc):
             cls = self.__class__
             expr = sympify(expr)
 
-        class_map = {(Hs, omegaExpr) : Homega,
-                     (Is, omegaExpr) : Iomega,
-                     (Vs, omegaExpr) : Vomega,
-                     (Ys, omegaExpr) : Yomega,
-                     (Zs, omegaExpr) : Zomega,
-                     (Admittance, omegaExpr) : Yomega,
-                     (Impedance, omegaExpr) : Zomega,                     
-                     (Hs, fExpr) : Hf,
-                     (Is, fExpr) : If,
-                     (Vs, fExpr) : Vf,
-                     (Ys, fExpr) : Yf,
-                     (Zs, fExpr) : Zf,
-                     (Admittance, fExpr) : Yf,
-                     (Impedance, fExpr) : Zf,                     
-                     (Hf, omegaExpr) : Homega,
-                     (If, omegaExpr) : Iomega,
-                     (Vf, omegaExpr) : Vomega,
-                     (Yf, omegaExpr) : Yomega,
-                     (Zf, omegaExpr) : Zomega,
-                     (Homega, fExpr) : Hf,
-                     (Iomega, fExpr) : If,
-                     (Vomega, fExpr) : Vf,
-                     (Yomega, fExpr) : Yf,
-                     (Zomega, fExpr) : Zf,
-                     (Admittance, sExpr) : Ys,
-                     (Impedance, sExpr) : Zs}                     
+        try:    
+            cls = self._subs_classes[new.__class__]
+        except:
+            class_map = {(Hs, omegaExpr) : Homega,
+                         (Is, omegaExpr) : Iomega,
+                         (Vs, omegaExpr) : Vomega,
+                         (Ys, omegaExpr) : Yomega,
+                         (Zs, omegaExpr) : Zomega,
+                         (Admittance, omegaExpr) : Yomega,
+                         (Impedance, omegaExpr) : Zomega,                     
+                         (Hs, fExpr) : Hf,
+                         (Is, fExpr) : If,
+                         (Vs, fExpr) : Vf,
+                         (Ys, fExpr) : Yf,
+                         (Zs, fExpr) : Zf,
+                         (Admittance, fExpr) : Yf,
+                         (Impedance, fExpr) : Zf,                     
+                         (Hf, omegaExpr) : Homega,
+                         (If, omegaExpr) : Iomega,
+                         (Vf, omegaExpr) : Vomega,
+                         (Yf, omegaExpr) : Yomega,
+                         (Zf, omegaExpr) : Zomega,
+                         (Homega, fExpr) : Hf,
+                         (Iomega, fExpr) : If,
+                         (Vomega, fExpr) : Vf,
+                         (Yomega, fExpr) : Yf,
+                         (Zomega, fExpr) : Zf,
+                         (Admittance, sExpr) : Ys,
+                         (Impedance, sExpr) : Zs}                     
 
-        if (self.__class__, new.__class__) in class_map:
-            cls = class_map[(self.__class__, new.__class__)]
+            if (self.__class__, new.__class__) in class_map:
+                cls = class_map[(self.__class__, new.__class__)]
 
         old = symbol_map(old)
         result = self.expr.subs(old, expr)
@@ -1230,7 +1248,14 @@ class Expr(ExprPrint, ExprMisc):
         return cls(result, **self.assumptions)
 
     def transform(self, arg, **assumptions):
-        """Transform into a different domain."""
+        """Transform into a different domain.
+
+        If arg is f, s, t, omega, jomega perform domain transformation,
+        otherwise perform substitution.
+
+        Note (5 * s)(omega) will fail since 5 * s is assumed not to be
+        causal and so Fourier transform is unknown.  However, Zs(5 *
+        s)(omega) will work since Zs is assumed to be causal."""
         
         from .transform import transform
         return transform(self, arg, **assumptions)
@@ -1248,14 +1273,13 @@ class Expr(ExprPrint, ExprMisc):
         See also evaluate.
 
         """
-
         if isinstance(arg, (tuple, list)):
             return [self._subs1(self.var, arg1) for arg1 in arg]
 
         if isinstance(arg, np.ndarray):
             return np.array([self._subs1(self.var, arg1) for arg1 in arg])
 
-        from .transform import call        
+        from .transform import call
         return call(self, arg, **assumptions)
 
     def limit(self, var, value, dir='+'):
@@ -1275,9 +1299,7 @@ class Expr(ExprPrint, ExprMisc):
         var = symbols[symbolnames.index(str(var))]
         
         ret = sym.limit(self.expr, var, value)
-        if hasattr(self, 'assumptions'):
-            return self.__class__(ret, **self.assumptions)
-        return self.__class__(ret)
+        return self.__class__(ret, **self.assumptions)
 
     def simplify(self):
         """Simplify expression."""
@@ -1352,7 +1374,7 @@ class Expr(ExprPrint, ExprMisc):
             arg = self.var
         arg = self._tweak_arg(arg)
             
-        return self.__class__(sym.diff(self.expr, arg))
+        return self.__class__(sym.diff(self.expr, arg), **self.assumptions)
 
     def diff(self, arg=None):
 
@@ -1377,7 +1399,8 @@ class Expr(ExprPrint, ExprMisc):
             arg = self.var
 
         arg = self._tweak_arg(arg)
-        return self.__class__(sym.integrate(self.expr, arg, **kwargs))
+        return self.__class__(sym.integrate(self.expr, arg, **kwargs),
+                              **self.assumptions)
 
     def solve(self, *symbols, **flags):
 
@@ -1390,7 +1413,7 @@ class Expr(ExprPrint, ExprMisc):
         symdict = {sym.name:sym for sym in self.free_symbols}
 
         # Look for V(s), etc.
-        funcdict = {atom.func.__name__:atom for atom in self.atoms(sym.function.AppliedUndef)}        
+        funcdict = {atom.func.__name__:atom for atom in self.atoms(AppliedUndef)}        
 
         symdict.update(funcdict)
         return symdict
@@ -1465,7 +1488,8 @@ class Expr(ExprPrint, ExprMisc):
         """
         if self._ratfun is None:
             return self.copy()
-        return self.__class__(self._ratfun.canonical(factor_const), **self.assumptions)
+        return self.__class__(self._ratfun.canonical(factor_const),
+                              **self.assumptions)
 
     def general(self):
         """Convert rational function to general form.  For example,
@@ -1488,11 +1512,14 @@ class Expr(ExprPrint, ExprMisc):
 
         See also canonical, standard, general, timeconst, and ZPK."""
 
-        if self._ratfun is None:
-            return self.copy()        
-        return self.__class__(self._ratfun.partfrac(combine_conjugates,
-                                                    damping),
-                              **self.assumptions)
+        try:
+            if self._ratfun is None:
+                return self.copy()        
+            return self.__class__(self._ratfun.partfrac(combine_conjugates,
+                                                        damping),
+                                  **self.assumptions)
+        except ValueError:
+            return self.as_sum().partfrac(combine_conjugates, damping)
 
     def recippartfrac(self, combine_conjugates=False, damping=None):
         """Convert rational function into partial fraction form
@@ -1754,6 +1781,87 @@ class Expr(ExprPrint, ExprMisc):
 
         return self.__class__(expr, **self.assumptions)
 
+    def as_N_D(self, monic_denominator=False):
+        """Responses due to a sum of delayed transient responses
+        cannot be factored into ZPK form with a constant delay.
+        For example, sometimes SymPy gives:
+
+            ⎛    s⋅τ     ⎞  -s⋅τ
+            ⎝V₁⋅ℯ    - V₂⎠⋅ℯ    
+        I = ────────────────────
+               s⋅(L⋅s + R)     
+
+        This method tries to extract the numerator and denominator
+        where the denominator is a polynomial.
+
+        N, D = I.as_N_D()
+
+                     -s⋅τ
+        N = V₁ - V₂⋅ℯ    
+        D =  s⋅(L⋅s + R)"""
+        
+        N = 1
+        D = 1
+        factors = self.expr.as_ordered_factors()
+
+        # I.as_ordered_factors()    
+        #
+        # ⎡1     1         s⋅τ        -s⋅τ⎤
+        # ⎢─, ───────, V₁⋅ℯ    - V₂, ℯ    ⎥
+        # ⎣s  L⋅s + R                     ⎦
+        
+        for factor in factors:
+            a, b = factor.as_numer_denom()
+            N *= a
+            if b.is_polynomial(self.var):
+                D *= b
+            else:
+                N /= b
+                
+        N = N.simplify()
+
+        if monic_denominator:
+            Dpoly = sym.Poly(D, self.var)            
+            LC = Dpoly.LC()
+            D = Dpoly.monic().as_expr()
+            N = (N / LC).simplify()
+                
+        return self.__class__(N, **self.assumptions), self.__class__(D, **self.assumptions)                
+
+    def as_sum(self):
+        """Responses due to a sum of delayed transient responses
+        cannot be factored into ZPK form with a constant delay.
+        For example, sometimes SymPy gives:
+
+            ⎛    s⋅τ     ⎞  -s⋅τ
+            ⎝V₁⋅ℯ    - V₂⎠⋅ℯ    
+        I = ────────────────────
+               s⋅(L⋅s + R)     
+
+        While this cannot be factored into ZPK form, it can be
+        expressed as a sum of ZPK forms or as a partial fraction
+        expansion.  However, SymPy does not play ball if trying to
+        express as a sum of terms:
+
+        I.as_ordered_terms()  
+                                                 
+        ⎡⎛    s⋅τ     ⎞  -s⋅τ⎤
+        ⎢⎝V₁⋅ℯ    - V₂⎠⋅ℯ    ⎥
+        ⎢────────────────────⎥
+        ⎣    s⋅(L⋅s + R)     ⎦
+
+        Instead, it appears necessary to split into N / D where
+        D is a polynomial.  Then N can be split.
+        """
+
+        N, D = self.as_N_D()
+        N = N.simplify()
+
+        result = 0
+        for term in N.expand().as_ordered_terms ():
+            result += term / D
+        return result
+               
     
 def expr(arg, **assumptions):
     """Create Lcapy expression from arg.
@@ -1766,11 +1874,15 @@ def expr(arg, **assumptions):
 
     For example, v = expr('3 * exp(-t / tau) * u(t)')
 
+    V = expr('5 * s', causal=True)
     """
 
     from .sym import tsym, fsym, ssym, omegasym
 
-    if isinstance(arg, (Expr, ExprList, ExprTuple, ExprDict)):
+    if isinstance(arg, Expr) and assumptions == {}:
+        return arg
+    
+    if isinstance(arg, (ExprList, ExprTuple, ExprDict)):
         return arg
     elif isinstance(arg, list):
         return ExprList(arg)
@@ -1778,7 +1890,7 @@ def expr(arg, **assumptions):
         return ExprTuple(arg)
     elif isinstance(arg, dict):
         return ExprDict(arg)    
-    
+
     expr = sympify(arg, **assumptions)
 
     symbols = expr.free_symbols
