@@ -9,12 +9,12 @@ from __future__ import division
 from .fourier import inverse_fourier_transform
 from .functions import exp
 from .sym import j, oo, pi
-from .dexpr import dExpr
+from .seqexpr import seqExpr
 from .dsym import nsym, ksym, zsym
 import sympy as sym
 
 
-class kExpr(dExpr):
+class kExpr(seqExpr):
 
     """Discrete Fourier domain expression or symbol."""
 
@@ -83,12 +83,12 @@ class kExpr(dExpr):
             
             N = sympify('N')
 
-        foo = self.expr * exp(2 * j * pi * nsym * ksym / N) / N
+        foo = self.expr * exp(2 * j * pi * nsym * ksym / N)
 
         if evaluate:
-            result = summation(foo, (ksym, 0, N))       
+            result = summation(foo, (ksym, 0, N - 1)) / N
         else:
-            result = Sum(foo, (ksym, 0, N))
+            result = Sum(foo, (ksym, 0, N - 1)) / N
 
         if hasattr(self, '_fourier_conjugate_class'):
             result = self._fourier_conjugate_class(result)
