@@ -5,20 +5,19 @@ Copyright 2020 Michael Hayes, UCECE
 """
 
 from __future__ import division
-from .dexpr import dExpr
+from .seqexpr import seqExpr
 from .functions import exp
 from .sym import j, oo, pi, fsym
 from .dsym import nsym, ksym, zsym, dt
 from .acdc import ACChecker, is_dc, is_ac, is_causal
 from .ztransform import ztransform
-from .sequence import Sequence
 from sympy import Sum, summation, limit
 
 
 __all__ = ('Hn', 'In', 'Vn', 'Yn', 'Zn')
 
 
-class nExpr(dExpr):
+class nExpr(seqExpr):
 
     """t-domain expression or symbol."""
 
@@ -134,18 +133,6 @@ class nExpr(dExpr):
 
         return self.__class__(limit(self.expr, self.var, oo))
 
-    def seq(self, nvals=None, evaluate=False):
-
-        if nvals is None:
-            nvals = (-10, 10)
-        if isinstance(nvals, tuple):
-            nvals = range(nvals[0], nvals[1] + 1)
-
-        nvals = list(nvals)
-        v = self(nvals)
-
-        return Sequence(v, nvals, evaluate, self.var)
-
     def DFT(self, N=None, evaluate=True):
 
         from .kexpr import k
@@ -159,9 +146,9 @@ class nExpr(dExpr):
         foo = self.expr * exp(-2 * j * pi * nsym * ksym / N)
 
         if evaluate:
-            result = summation(foo, (nsym, 0, N))                        
+            result = summation(foo, (nsym, 0, N - 1))
         else:
-            result = Sum(foo, (nsym, 0, N))
+            result = Sum(foo, (nsym, 0, N - 1))
 
         if hasattr(self, '_fourier_conjugate_class'):
             result = self._fourier_conjugate_class(result)
@@ -178,9 +165,9 @@ class nExpr(dExpr):
     def extent(self, n1=-100, n2=100):
         """Determine extent of the signal.
 
-        For example, nexpr([1, 1]).extent = 2
-                     nexpr([1, 0, 1]).extent = 3
-                     nexpr([0, 1, 0, 1]).extent = 3
+        For example, nexpr([1, 1]).extent() = 2
+                     nexpr([1, 0, 1]).extent() = 3
+                     nexpr([0, 1, 0, 1]).extent() = 3
 
         This performs a search between n=n1 and n=n2."""
 
