@@ -343,12 +343,12 @@ class ParSer(OnePort):
 
         return '$%s$' % self.latex()
 
-    def pretty(self):
+    def pretty(self, **kwargs):
 
         str = ''
 
         for m, arg in enumerate(self.args):
-            argstr = arg.pretty()
+            argstr = arg.pretty(**kwargs)
 
             if isinstance(arg, ParSer) and arg.__class__ != self.__class__:
                 argstr = '(' + argstr + ')'
@@ -1301,7 +1301,7 @@ from .expr import Expr
 from .cexpr import cExpr, Iconst, Vconst
 from .sexpr import sExpr, Is, Vs, Ys, Zs
 from .texpr import tExpr
-from .noisy import Inoisy, Vnoisy
+from .noiseomegaexpr import Inoisy, Vnoisy
 from .voltage import Voltage
 from .current import Current
 from .phasor import Iphasor, Vphasor
