@@ -7,7 +7,7 @@ Copyright 2016--2020 Michael Hayes, UCECE
 from __future__ import division
 import sympy as sym
 from sympy.core.mul import _unevaluated_Mul as uMul
-from .sym import sympify
+from .sym import sympify, AppliedUndef
 
 class Pole(object):
 
@@ -269,7 +269,7 @@ def as_ratfun_delay_undef(expr, var):
                 if c[1] != 0:
                     rf *= sym.exp(c[1])
                 continue
-        if isinstance(f, sym.function.AppliedUndef):
+        if isinstance(f, AppliedUndef):
             undef *= f
             continue
                 
@@ -322,7 +322,7 @@ class Ratfun(object):
         F = sym.factor(expr).as_ordered_factors()
 
         for f in F:
-            if isinstance(f, sym.function.AppliedUndef):
+            if isinstance(f, AppliedUndef):
                 undef *= f
                 continue
             if not f.has(var):
@@ -442,7 +442,7 @@ class Ratfun(object):
         numer, denom = self.numerator_denominator
         return denom
 
-    def canonical(self, factor_const=False):
+    def canonical(self, factor_const=True):
         """Convert rational function to canonical form; this is like general
         form but with a unity highest power of denominator.  For
         example,
@@ -473,19 +473,20 @@ class Ratfun(object):
                 K *= sym.exp(self.var * delay)
 
             # Divide by leading coefficient
-            Nm = Npoly.monic()
-            Dm = Dpoly.monic()
+            N = Npoly.monic().as_expr()
+            D = Dpoly.monic().as_expr()
 
-            expr = K * (Nm / Dm) * undef
+            expr = sym.Mul(K, sym.Mul(N, 1 / D, evaluate=False), undef,
+                           evaluate=False)
         else:
             C = Dpoly.LC()
-            Dm = Dpoly.monic()
-            Nm = (Npoly / C).simplify()
-            expr = Nm / Dm
+            D = Dpoly.monic().as_expr()
+            N = (Npoly.as_expr() / C).simplify()
+            expr = sym.Mul(N, 1 / D, evaluate=False)
             if delay != 0:
                 expr *= sym.exp(self.var * delay)
             expr *= undef
-
+            
         return expr
 
     def general(self):
