@@ -6,6 +6,7 @@ Usage: schtex infile.sch [outfile.tex|pdf|png|svg|sch|pgf]
 """
 
 from __future__ import print_function
+from matplotlib.pyplot import show
 from argparse import ArgumentParser
 import sys
 import os
@@ -118,7 +119,7 @@ def main (argv=None):
     
     parser.add_argument('--stage', type=int,
                         dest='stage', default=0,
-                        help='graph analysis stage')
+                        help='select graph analysis stage 0--4')
     
     parser.add_argument('--pdb', action='store_true',
                         default=False,
@@ -126,7 +127,7 @@ def main (argv=None):
     
     parser.add_argument('--renumber', type=str,
                         dest='renumber', default=None,
-                        help='renumber nodes, e.g, 10:1, 11:2')
+                        help='renumber nodes, e.g, 10:1, 11:2 or all')
 
     parser.add_argument('--font', type=str, default=None,
                         help=r'specify default font, e.g., \small, \sffamily\tiny')    
@@ -143,6 +144,10 @@ def main (argv=None):
     parser.add_argument('filename', type=str, help='schematic filename')
     parser.add_argument('outfilename', type=str, nargs='?',
                         help='output filename', default=None)    
+
+    parser.add_argument('--show', action='store_true',
+                        dest='show', default=None,
+                        help="show image")
     
     args = parser.parse_args()    
 
@@ -166,7 +171,9 @@ def main (argv=None):
     if args.noisy_model:
         cct = cct.noisy()        
 
-    if args.renumber:
+    if args.renumber == 'all':
+       cct = cct.renumber()
+    elif args.renumber:
         parts = args.renumber.split(',')
         node_map = {}
         for part in parts:
@@ -213,15 +220,16 @@ def main (argv=None):
                  dpi=args.dpi, nosave=nosave, **kwargs)
 
     if args.xgraph:
-        cct.sch.make_graphs()
+        cct.sch.make_graphs(debug=args.debug)
         cct.sch.xgraph.dot(outfilename, stage=args.stage)
-        return 0
 
     if args.ygraph:
-        cct.sch.make_graphs()
+        cct.sch.make_graphs(debug=args.debug)
         cct.sch.ygraph.dot(outfilename, stage=args.stage)
-        return 0
 
+    if args.show:
+        show()
+        
     return 0
 
 
