@@ -60,7 +60,7 @@ class StateSpace(object):
         cpt_map = {}
 
         for key, elt in cct.elements.items():
-            ssnet = elt.ss_model()
+            ssnet = elt._ss_model()
             sselt = sscct._add(ssnet)
             name = elt.name
             cpt_map[name] = sselt.name
@@ -265,7 +265,7 @@ class StateSpace(object):
     def characteristic_polynomial(self):
         """Characteristic polynomial (aka system polynomial).
 
-        lambda(s) = |s * I - A|"""
+        `lambda(s) = |s * I - A|`"""
 
         M = Matrix(sym.eye(len(self.x)) * ssym - self.A)        
         return sExpr(M.det()).simplify()
@@ -274,7 +274,7 @@ class StateSpace(object):
     def P(self):
         """Characteristic polynomial (aka system polynomial).
 
-        lambda(s) = |s * I - A|"""        
+        `lambda(s) = |s * I - A|`"""        
 
         return self.characteristic_polynomial().canonical()
 
