@@ -30,15 +30,15 @@ class LcapyTester(unittest.TestCase):
         a.add('R1 1 2')
         a.add('C1 2 0')
 
-        self.assertEqual2(a.Z(1, 2), R('R1').Z, "Z incorrect for R1.")
-        self.assertEqual2(a.Z(2, 0), C('C1').Z, "Z incorrect for C1.")
+        self.assertEqual2(a.impedance(1, 2), R('R1').impedance, "Z incorrect for R1.")
+        self.assertEqual2(a.impedance(2, 0), C('C1').impedance, "Z incorrect for C1.")
         self.assertEqual2(
-            a.Z(1, 0), (R('R1') + C('C1')).Z, "Z incorrect for R1 + C1.")
+            a.impedance(1, 0), (R('R1') + C('C1')).impedance, "Z incorrect for R1 + C1.")
 
-        self.assertEqual2(a.Y(1, 2), R('R1').Y, "Y incorrect for R1.")
-        self.assertEqual2(a.Y(2, 0), C('C1').Y, "Y incorrect for C1.")
+        self.assertEqual2(a.admittance(1, 2), R('R1').Y, "Y incorrect for R1.")
+        self.assertEqual2(a.admittance(2, 0), C('C1').Y, "Y incorrect for C1.")
         self.assertEqual2(
-            a.Y(1, 0), (R('R1') + C('C1')).Y, "Y incorrect for R1 + C1.")
+            a.admittance(1, 0), (R('R1') + C('C1')).Y, "Y incorrect for R1 + C1.")
         self.assertEqual2(a.Isc(1, 0), I(0).Isc, "Isc incorrect")
         self.assertEqual(a.R1.Z, expr('R1'), "Z incorrect")
         self.assertEqual(a.R1.R, expr('R1'), "R incorrect")
@@ -59,17 +59,17 @@ class LcapyTester(unittest.TestCase):
 
         # Note, V1 acts as a short-circuit for the impedance/admittance
         self.assertEqual2(
-            a.Z(1, 2), (R('R1') | C('C1')).Z, "Z incorrect across R1")
+            a.impedance(1, 2), (R('R1') | C('C1')).Z, "Z incorrect across R1")
         self.assertEqual2(
-            a.Z(2, 0), (R('R1') | C('C1')).Z, "Z incorrect across C1")
-        self.assertEqual2(a.Z(1, 0), R(0).Z, "Z incorrect across V1")
+            a.impedance(2, 0), (R('R1') | C('C1')).Z, "Z incorrect across C1")
+        self.assertEqual2(a.impedance(1, 0), R(0).Z, "Z incorrect across V1")
 
         self.assertEqual2(
-            a.Y(1, 2), (R('R1') | C('C1')).Y, "Y incorrect across R1")
+            a.admittance(1, 2), (R('R1') | C('C1')).Y, "Y incorrect across R1")
         self.assertEqual2(
-            a.Y(2, 0), (R('R1') | C('C1')).Y, "Y incorrect across C1")
+            a.admittance(2, 0), (R('R1') | C('C1')).Y, "Y incorrect across C1")
         # This has a non-invertible A matrix.
-        # self.assertEqual2(a.Y(1, 0), R(0).Y, "Y incorrect across V1")
+        # self.assertEqual2(a.admittance(1, 0), R(0).Y, "Y incorrect across V1")
 
         self.assertEqual2(a.Voc(1, 0).s, V('V1 / s').Voc.s, "Voc incorrect across V1")
         self.assertEqual(a.is_ivp, False, "Initial value problem incorrect")
@@ -93,23 +93,23 @@ class LcapyTester(unittest.TestCase):
         self.assertEqual2(
             a.thevenin(1, 2).Voc, a.Voc(1, 2), "incorrect thevenin voltage")
         self.assertEqual2(
-            a.thevenin(1, 2).Z, a.Z(1, 2), "incorrect thevenin impedance")
+            a.thevenin(1, 2).Z, a.impedance(1, 2), "incorrect thevenin impedance")
         self.assertEqual2(
             a.norton(1, 2).Isc, a.Isc(1, 2), "incorrect norton current")
         self.assertEqual2(
-            a.norton(1, 2).Y, a.Y(1, 2), "incorrect norton admittance")
+            a.norton(1, 2).Y, a.admittance(1, 2), "incorrect norton admittance")
         self.assertEqual2(
-            a.Z(1, 2), (R('R1') | L('L1')).Z, "Z incorrect across R1")
+            a.impedance(1, 2), (R('R1') | L('L1')).Z, "Z incorrect across R1")
         self.assertEqual2(
-            a.Z(2, 0), (R('R1') | L('L1')).Z, "Z incorrect across L1")
-        self.assertEqual2(a.Z(1, 0), R(0).Z, "Z incorrect across V1")
+            a.impedance(2, 0), (R('R1') | L('L1')).Z, "Z incorrect across L1")
+        self.assertEqual2(a.impedance(1, 0), R(0).Z, "Z incorrect across V1")
 
         self.assertEqual2(
-            a.Y(1, 2), (R('R1') | L('L1')).Y, "Y incorrect across R1")
+            a.admittance(1, 2), (R('R1') | L('L1')).Y, "Y incorrect across R1")
         self.assertEqual2(
-            a.Y(2, 0), (R('R1') | L('L1')).Y, "Y incorrect across L1")
+            a.admittance(2, 0), (R('R1') | L('L1')).Y, "Y incorrect across L1")
         # This has a non-invertible A matrix.
-        # self.assertEqual2(a.Y(1, 0), R(0).Y, "Y incorrect across V1")
+        # self.assertEqual2(a.admittance(1, 0), R(0).Y, "Y incorrect across V1")
 
         self.assertEqual2(a.Voc(1, 0), V('V1' / s).Voc,
                           "Voc incorrect across V1")
@@ -301,67 +301,6 @@ class LcapyTester(unittest.TestCase):
 
         self.assertEqual2(H, 1 / (s * 'R1' * 'C1' + 1),  "Incorrect ratio")
     
-    def test_noise1(self):
-        """Lcapy: check circuit noise for voltage divider"""
-
-        a = Circuit()
-        a.add('V1 1 0 noise 3') 
-        a.add('R1 1 2 2')
-        a.add('R2 2 0 4')
-        V1 = a.R1.V.n
-        self.assertEqual2(V1, Vnoisy(1, nid=V1.nid), "Incorrect ratio")
-
-    def test_noise2(self):
-        """Lcapy: check circuit noise for pair of sources"""
-
-        a = Circuit()
-        a.add('V1 1 0 noise 3')
-        a.add('V2 2 1 noise 4')
-        a.add('R1 2 0 5')
-        V1 = a.R1.V.n
-        self.assertEqual2(V1, Vnoisy(5, nid=V1.nid), "Incorrect noise sum")        
-        
-    def test_filtered_noise1(self):
-        """Lcapy: check circuit filtered noise"""
-
-        a = Circuit()
-        a.add('V1 1 0 noise 3') 
-        a.add('R1 1 2 2')
-        a.add('C1 2 0 4')         
-#        self.assertEqual2(a.R1.V.n, Vnoisy(1), "Incorrect ratio")
-
-
-    def test_filtered_noise2(self):
-        """Lcapy: check circuit filtered noise"""
-
-        a = Circuit()
-        a.add('V1 1 0 noise {sqrt(4 * k * T * R)}') 
-        a.add('R1 1 2 R')
-        a.add('C1 2 0 C')         
-        self.assertEqual2(a.C1.V.n.rms(), Vt('sqrt(k * T / C)'),
-                          "Incorrect capacitor voltage")
-
-    def test_filtered_noise3(self):
-        """Lcapy: check circuit filtered noise"""
-
-        a = Circuit()
-        a.add('V1 1 0 noise 20') 
-        a.add('R1 1 2 1')
-        a.add('C1 2 0 2')         
-        self.assertEqual(a.C1.V.n.rms(), 5 * sqrt(2),
-                         "Incorrect capacitor voltage")
-
-    def test_noisy1(self):
-
-        a = Circuit()
-        a.add('R1 1 0')
-        a.add('R2 1 0')
-        an = a.noisy()
-        b = Circuit()
-        b.add('R1 1 0 {R1 * R2 / (R1 + R2)}')
-        bn = b.noisy()
-        self.assertEqual(an[1].V.n.expr, bn[1].V.n.expr, "Incorrect noise")
-
     def test_causal1(self):
 
         a = Circuit()
@@ -585,7 +524,7 @@ class LcapyTester(unittest.TestCase):
         W 0_2 0_3; right
         K L1 L2 1; invisible""")
 
-        self.assertEqual(a.R1.v, expr('V1 * cos(omega * t) * abs(omega) / omega'),
+        self.assertEqual(a.R1.v, expr('V1 * cos(omega_0 * t) * abs(omega_0) / omega_0'),
                          "coupling incorrect")
         
 
@@ -611,4 +550,10 @@ class LcapyTester(unittest.TestCase):
         self.assertEqual(d.R.V, 6, "incorrect voltage with all killed except V1")
         
         
-        
+    def test_TF(self):
+
+        a = Circuit("""
+        TF 2 0 1 0 k
+        R 2 0""")        
+
+        self.assertEqual(a.impedance(1, 0), expr('R / k**2'), "incorrect impedance")
