@@ -1,4 +1,4 @@
-"""This file provides the zExpr class to represent z-domain expressions.
+"""This module provides the zExpr class to represent z-domain expressions.
 
 Copyright 2020 Michael Hayes, UCECE
 
@@ -13,8 +13,9 @@ from .ratfun import _zp2tf, Ratfun
 from .dexpr import dExpr
 from .expr import symbol, expr, ExprDict
 from .functions import sqrt, exp
-import sympy as sym
 import numpy as np
+from sympy import Eq, div, limit, oo
+
 
 __all__ = ('Hz', 'Iz', 'Vz', 'Yz', 'Zz')
 
@@ -47,12 +48,12 @@ class zExpr(dExpr):
     def initial_value(self):
         """Determine value at n = 0."""
 
-        return self.__class__(sym.limit(self.expr * self.var, self.var, sym.oo))
+        return self.__class__(limit(self.expr * self.var, self.var, oo))
 
     def final_value(self):
         """Determine value at n = oo."""
 
-        return self.__class__(sym.limit(self.expr * self.var, self.var, 0))
+        return self.__class__(limit(self.expr * self.var, self.var, 0))
 
     def inverse_ztransform(self, **assumptions):
         """Attempt inverse Znransform transform.
@@ -124,7 +125,7 @@ class zExpr(dExpr):
 
         # Perform polynomial long division so expr = Q + M / D                
         N, D, delay = self._decompose()
-        Q, M = sym.div(N, D)
+        Q, M = div(N, D)
         expr = M / D
 
         N = len(t)
@@ -199,7 +200,54 @@ class zExpr(dExpr):
         """Convert to Fourier domain using discrete time Fourier transform."""
     
         return self.discrete_time_fourier_transform(**assumptions) 
+
+    def decompose_AB(self):
+
+        C, R = self.factor_const()
+        
+        invz = expr('invz')
+        H = R.replace(z, 1 / invz).factor()
+        r = Ratfun(H, invz.expr)
+        B = zExpr(r.N).replace(invz, 1 / z)
+        A = zExpr(r.D).replace(invz, 1 / z)
+
+        C1, R1 = A.term_const()
+        if C1.is_negative:
+            A = -A
+            B = -B
+        
+        return A, B * C
     
+    def difference_equation(self, input='x', output='y', form='iir'):
+        """Create difference equation from transfer function.
+
+        form can be 'fir' or 'iir' ('direct form I').
+        """
+
+        H = self
+        x = nexpr('%s(n)' % input)
+        y = nexpr('%s(n)' % output)
+
+        X = x.ZT()
+        Y = y.ZT()
+
+        if form in ('iir', 'direct form I'):
+            # Direct form I
+            A, B = self.decompose_AB()
+            
+            lhs = (A * Y).IZT(causal=True)
+            rhs = (B * X).IZT(causal=True)
+            
+        elif form == 'fir':
+            H = H.partfrac()
+            lhs = y
+            rhs = (H * X).IZT(causal=True)
+
+        else:
+            raise ValueError('Unhandled form ' + form)    
+
+        return nExpr(Eq(lhs.expr, rhs.expr))        
+        
     
 # Perhaps use a factory to create the following classes?
 
@@ -288,14 +336,13 @@ class ZzVector(Vector):
     _typewrap = Zz
 
 
-def zexpr(arg):
+def zexpr(arg, **assumptions):
     """Create zExpr object.  If `arg` is zsym return z"""
 
     if arg is zsym:
         return z
-    return zExpr(arg)
+    return zExpr(arg, **assumptions)
 
 
-from .nexpr import Hn, In, Vn, Yn, Zn, nExpr
+from .nexpr import Hn, In, Vn, Yn, Zn, nExpr, nexpr
 z = zExpr('z')
-
